Off[General::spell]

Model`Name = "DarkBS";
Model`NameLaTeX ="DarkBS";
Model`Authors = "D. Sierra, F.Staub, A.Vicente";
Model`Date = "2015-03-11";


(*-------------------------------------------*)
(*   Particle Content*)
(*-------------------------------------------*)

(* Global Symmetries *)
Global[[1]] = {Z[2], Z2};

(* Gauge Groups *)

Gauge[[1]]={B,   U[1], hypercharge, g1,False,1};
Gauge[[2]]={WB, SU[2], left,        g2,True,1};
Gauge[[3]]={G,  SU[3], color,       g3,False,1};
Gauge[[4]]={Bp,  U[1], Uchi,        gX,False,1};


(* Matter Fields *)

FermionFields[[1]] = {q, 3, {uL, dL},     1/6, 2,  3, 0, 1};  
FermionFields[[2]] = {l, 3, {vL, eL},    -1/2, 2,  1, 0, 1};
FermionFields[[3]] = {d, 3, conj[dR],     1/3, 1, -3, 0, 1};
FermionFields[[4]] = {u, 3, conj[uR],    -2/3, 1, -3, 0, 1};
FermionFields[[5]] = {e, 3, conj[eR],       1, 1,  1, 0, 1};

FermionFields[[6]] = {lL, 1, {v4, e4},    -1/2, 2,  1,  2, 1};
FermionFields[[7]] = {lR, 1, {e5, v5},     1/2, 2,  1, -2, 1};
FermionFields[[8]] = {qL, 1, {u4, d4},     1/6, 2,  3,  2, 1};
FermionFields[[9]] = {qR, 1, {d5, u5},    -1/6, 2, -3, -2, 1};    

ScalarFields[[1]] =  {H, 1, {Hp, H0},   1/2, 2,  1,  0,  1};
ScalarFields[[2]] =  {Phi, 1, phi,        0, 1,  1,  2,  1};
ScalarFields[[3]] =  {Chi, 1, chi,        0, 1,  1, -1, -1};

        
(*----------------------------------------------*)
(*   DEFINITION                                 *)
(*----------------------------------------------*)

NameOfStates={GaugeES, EWSB};

(* ----- Before EWSB ----- *)

DEFINITION[GaugeES][LagrangianInput]= {
	{LagHC, {AddHC->True}},
	{LagNoHC,{AddHC->False}}
};

LagNoHC = -mH2 conj[H].H - mPhi2 Phi.conj[Phi] - mChi2 Chi.conj[Chi] - 1/2 \[Lambda] conj[H].H.conj[H].H \
-1/2 LamP Phi.conj[Phi].Phi.conj[Phi] -1/2 LamC Chi.conj[Chi].Chi.conj[Chi] \
- LamCP conj[Phi].Phi.conj[Chi].Chi - LamHP conj[H].H.conj[Phi].Phi - LamHC conj[H].H.conj[Chi].Chi;
LagHC =  -(Yd conj[H].d.q + Ye conj[H].e.l + Yu H.u.q + mQ qL.qR + mL lL.lR + lamQ Phi.qR.q + lamL Phi.lR.l );


(* Gauge Sector *)

DEFINITION[EWSB][GaugeSector] =
{ 
  {{VB,VWB[3],VBp},{VP,VZ,VZp},ZZ},
  {{VWB[1],VWB[2]},{VWp,conj[VWp]},ZW}
};     
        

(* ----- VEVs ---- *)

DEFINITION[EWSB][VEVs]= 
{    {H0, {v, 1/Sqrt[2]}, {sigmaH, \[ImaginaryI]/Sqrt[2]},{phiH, 1/Sqrt[2]}},
     {phi, {vP, 1/Sqrt[2]}, {sigmaP, \[ImaginaryI]/Sqrt[2]},{phiP, 1/Sqrt[2]}}      };
 

DEFINITION[EWSB][MatterSector]=   {
    {{phiH,phiP},{hh,ZH}},
    {{sigmaH,sigmaP},{Ah,ZA}},
    {{{dL,d4}, {conj[dR],d5}}, {{DL,Vd}, {DR,Ud}}},
    {{{uL,u4}, {conj[uR],u5}}, {{UL,Vu}, {UR,Uu}}},
    {{{eL,e4}, {conj[eR],e5}}, {{EL,Ve}, {ER,Ue}}},
    {{vL,v4,v5},{VL,UV}}
};  


(*------------------------------------------------------*)
(* Dirac-Spinors *)
(*------------------------------------------------------*)

DEFINITION[EWSB][DiracSpinors]={
 Fd ->{  DL, conj[DR]},
 Fe ->{  EL, conj[ER]},
 Fu ->{  UL, conj[UR]},
 Fv ->{  VL, conj[VL]}};

DEFINITION[EWSB][GaugeES]={
 Fd1 ->{  FdL, 0},
 Fd2 ->{  0, FdR},
 Fu1 ->{  Fu1, 0},
 Fu2 ->{  0, Fu2},
 Fe1 ->{  Fe1, 0},
 Fe2 ->{  0, Fe2}};
