ParameterDefinitions = { 

{g1,        { Description -> "Hypercharge-Coupling"}},
{g2,        { Description -> "Left-Coupling"}},
{g3,        { Description -> "Strong-Coupling"}},    


{gX,       {LaTeX -> "g_X",
             LesHouches -> {GAUGE,4},
             OutputName -> gX}},

{g1X,       {LaTeX -> "\\tilde{g}",
             LesHouches -> {GAUGE,10},
             OutputName -> g1X}},
{gX1,       {LaTeX -> "\\bar{g}",
             LesHouches -> {GAUGE,11},
             OutputName -> gX1}},


{AlphaS,    {Description -> "Alpha Strong"}},	
{e,         { Description -> "electric charge"}}, 

{Gf,        { Description -> "Fermi's constant"}},
{aEWinv,    { Description -> "inverse weak coupling constant at mZ"}},

{Yu,        { Description -> "Up-Yukawa-Coupling",
	      DependenceNum ->  Sqrt[2]/v* {{Mass[Fu,1],0,0},
             				    {0, Mass[Fu,2],0},
             				    {0, 0, Mass[Fu,3]}}}}, 
             									
{Yd,        { Description -> "Down-Yukawa-Coupling",
	      DependenceNum ->  Sqrt[2]/v* {{Mass[Fd,1],0,0},
					    {0, Mass[Fd,2],0},
					    {0, 0, Mass[Fd,3]}}}},
             									
{Ye,        { Description -> "Lepton-Yukawa-Coupling",
	      DependenceNum ->  Sqrt[2]/v* {{Mass[Fe,1],0,0},
					    {0, Mass[Fe,2],0},
					    {0, 0, Mass[Fe,3]}}}}, 
                                                                            
{\[Lambda],  { Description -> "SM Higgs Selfcouplings",
               DependenceNum -> Mass[hh]^2/(2 v^2)}},
{v,          { Description -> "EW-VEV",
               DependenceNum -> Sqrt[4*Mass[VWp]^2/(g2^2)],
               DependenceSPheno -> None  }},

{vP,   {LaTeX ->"v_\\phi",
        OutputName -> vP,
        LesHouches -> {DBS,20}}},

{mPhi2, {LaTeX -> "m_{\\phi}^2",
         OutputName->mPhi2,
         LesHouches ->  {DBS,1}}},

{mChi2, {LaTeX -> "m_{\\chi}^2",
         OutputName->mX2,
         LesHouches ->  {DBS,2}}},

{mQ, {LaTeX -> "m_Q",
      OutputName->mQ,
      LesHouches ->  {DBS,3}}},

{mL, {LaTeX -> "m_L",
      OutputName->mL,
      LesHouches ->  {DBS,4}}},


{LamP, {LaTeX -> "\\lambda_{\\phi}",
        OutputName->LamP,
        LesHouches ->  {DBS,10}}},

{LamC, {LaTeX -> "\\lambda_{\\chi}",
        OutputName->LamC,
        LesHouches ->  {DBS,11}}},

{LamCP, {LaTeX -> "\\lambda_{\\phi\\chi}",
         OutputName->LamCP,
         LesHouches ->  {DBS,12}}},

{LamHP, {LaTeX -> "\\lambda_{H\\phi}",
         OutputName->LamHP,
         LesHouches ->  {DBS,13}}},

{LamHC, {LaTeX -> "\\lambda_{H\\chi}",
         OutputName->LamHC,
         LesHouches ->  {DBS,14}}},

{lamQ, {LaTeX -> "\\lambda_Q",
        OutputName->lamQ,
        LesHouches ->  LAMQ}},

{lamL, {LaTeX -> "\\lambda_L",
        OutputName->lamL,
        LesHouches ->  LAML}},


{mH2,       { Description -> "SM Higgs Mass Parameter"}},

{ThetaW,    { Description -> "Weinberg-Angle",
              DependenceNum -> ArcSin[Sqrt[1 - Mass[VWp]^2/Mass[VZ]^2]]  }},

{ThetaWp,  { LaTeX -> "{\\Theta'}_W",
             Real ->True,
             DependenceSPheno -> ArcCos[Abs[ZZ[3,3]]],
             OutputName-> TWp,
             LesHouches -> {ANGLES,10}      }}, 


{ZH, { Description->"Scalar-Mixing-Matrix", 
       LaTeX -> "Z^H",
       Real -> True, 
       DependenceOptional ->   {{-Sin[\[Alpha]],Cos[\[Alpha]]},
                                {Cos[\[Alpha]],Sin[\[Alpha]]}}, 
       Value -> None, 
       LesHouches -> SCALARMIX,
       OutputName-> ZH     }},
             
{ZA, { Description->"Pseudo-Scalar-Mixing-Matrix", 
       LaTeX -> "Z^A",
       Real -> True,
       DependenceOptional -> {{-Cos[\[Beta]],Sin[\[Beta]]},
                              {Sin[\[Beta]],Cos[\[Beta]]}}, 
       Value -> None, 
       LesHouches -> PSEUDOSCALARMIX,
       OutputName-> ZA      }},

{\[Beta],   { Description -> "Pseudo Scalar mixing angle",
              DependenceSPheno -> ArcSin[Abs[ZH[1,2]]]  }},             

{\[Alpha],  { Description -> "Scalar mixing angle" }},  

{UV, { Description ->"Neutrino-Mixing-Matrix", 
       LaTeX -> "U^V",
       Dependence ->  None, 
       Value -> None, 
       LesHouches -> UVMIX,
       OutputName-> UV      }},

{ZZ, { Description -> "Photon-Z Mixing Matrix",
       Dependence->  {{Cos[ThetaW],-Sin[ThetaW] Cos[ThetaWp], Sin[ThetaW] Sin[ThetaWp]},                             
                      {Sin[ThetaW],Cos[ThetaW] Cos[ThetaWp],-Cos[ThetaW] Sin[ThetaWp]},
                      {0, Sin[ThetaWp], Cos[ThetaWp]}} }},

{ZW, { Description -> "W Mixing Matrix",
       Dependence ->   1/Sqrt[2] {{1, 1},
                                  {\[ImaginaryI],-\[ImaginaryI]}} }},

{Vu,        {Description ->"Left-Up-Mixing-Matrix"}},
{Vd,        {Description ->"Left-Down-Mixing-Matrix"}},
{Uu,        {Description ->"Right-Up-Mixing-Matrix"}},
{Ud,        {Description ->"Right-Down-Mixing-Matrix"}}, 
{Ve,        {Description ->"Left-Lepton-Mixing-Matrix"}},
{Ue,        {Description ->"Right-Lepton-Mixing-Matrix"}}

 }; 
